SourceConfig

Struct SourceConfig 

pub struct SourceConfig {
    pub name: String,
    pub optional: bool,
    pub priority: i32,
    pub cache: bool,
    pub format: Option<String>,
    pub path: Option<PathBuf>,
    pub url: Option<String>,
    pub env_prefix: Option<String>,
    pub extra: BTreeMap<String, String>,
}
Configuration for a single source.

Describes how to load configuration from a specific source.

Fields

name: String

Name/identifier for this source.

optional: bool

Whether this source is optional.

priority: i32

Priority for this source (higher = more important).

cache: bool

Whether to cache the loaded content.

format: Option<String>

Format override (auto-detected if None).

path: Option<PathBuf>

Source-specific path (for file sources).

url: Option<String>

Source-specific URL for custom URL-backed sources.

env_prefix: Option<String>

Source-specific environment variable prefix.

extra: BTreeMap<String, String>

Additional source-specific options.

Implementations

Source

impl SourceConfig

pub fn new(name: impl Into<String>) -> Self

Create a new source config with the given name.

pub fn builder() -> SourceConfigBuilder

Create a builder for constructing a SourceConfig.

pub fn file(path: impl Into<PathBuf>) -> Self

Create a file source config.

pub fn env(prefix: impl Into<String>) -> Self

Create an environment source config.

pub const fn is_optional(&self) -> bool

Check if this is an optional source.

pub fn display_id(&self) -> String

Get the display identifier for this source.